/**
 * Interface for proxy statistics and metrics
 */
export interface IProxyStats {
  /**
   * Get the current number of active connections
   */
  getActiveConnections(): number;
  
  /**
   * Get connection counts grouped by route name
   */
  getConnectionsByRoute(): Map<string, number>;
  
  /**
   * Get connection counts grouped by IP address
   */
  getConnectionsByIP(): Map<string, number>;
  
  /**
   * Get the total number of connections since proxy start
   */
  getTotalConnections(): number;
  
  /**
   * Get the current requests per second rate
   */
  getRequestsPerSecond(): number;
  
  /**
   * Get total throughput (bytes transferred)
   */
  getThroughput(): { bytesIn: number; bytesOut: number };
}

/**
 * Extended interface for additional metrics helpers
 */
export interface IProxyStatsExtended extends IProxyStats {
  /**
   * Get throughput rate (bytes per second) for last minute
   */
  getThroughputRate(): { bytesInPerSec: number; bytesOutPerSec: number };
  
  /**
   * Get top IPs by connection count
   */
  getTopIPs(limit?: number): Array<{ ip: string; connections: number }>;
  
  /**
   * Check if an IP has reached the connection limit
   */
  isIPBlocked(ip: string, maxConnectionsPerIP: number): boolean;
}